@@ -6,7 +6,7 @@
 
 TMP_OUT=$OUT
 
-for ARCH in i386 m68k alpha sparc powerpc arm
+for ARCH in i386 alpha arm hppa ia64 m68k mips mipsel powerpc s390 sparc
 do
 	export ARCH
 	echo "Now we're going to build CD for $ARCH !"
@@ -14,29 +14,36 @@ do
 	make distclean
 	make ${CODENAME}_status
 	echo " ... checking your mirror"
-	make mirrorcheck
+	if [ "$SKIPMIRRORCHECK" != "yes" ] ; then 
+		make mirrorcheck
+	else
+		echo "WARNING: skipping mirrorcheck"
+	fi
+
 	if [ $? -gt 0 ]; then
 		echo "ERROR: Your mirror has a problem, please correct it." >&2
 		exit 1
 	fi
 	echo " ... selecting packages to include"
-    if [ -e ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. ] ; then
-            disks=`du -sm ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. | \
+	if [ -e ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. ] ; then
+		disks=`du -sm ${MIRROR}/dists/${CODENAME}/main/disks-${ARCH}/current/. | \
 				awk '{print $1}'`
-    else
-            disks=0
-    fi
+	else
+		disks=0
+	fi
 	if [ -f $BASEDIR/tools/boot/$CODENAME/boot-$ARCH.calc ]; then
 	    . $BASEDIR/tools/boot/$CODENAME/boot-$ARCH.calc
 	fi
 	SIZE_ARGS=''
-	for CD in 1 2 3 4; do
+	for CD in 1 2 3 4 5 6 7 8; do
 		size=`eval echo '$'"BOOT_SIZE_${CD}"`
 		[ "$size" = "" ] && size=0
 		[ $CD = "1" ] && size=$(($size + $disks))
-		SIZE_ARGS="$SIZE_ARGS SIZELIMIT${CD}=$(((630 - $size) * 1024 *1024))"
+        FULL_SIZE=`echo "($DEFBINSIZE - $size) * 1024 * 1024" | bc`
+        SIZE_ARGS="$SIZE_ARGS SIZELIMIT${CD}=$FULL_SIZE"
 	done
-	make list COMPLETE=1 $SIZE_ARGS SRCSIZELIMIT=$((635 * 1024 * 1024))
+    FULL_SIZE=`echo "($DEFSRCSIZE - $size) * 1024 * 1024" | bc`
+    make list COMPLETE=1 $SIZE_ARGS SRCSIZELIMIT=$FULL_SIZE
 	echo " ... building the images"
 	if [ "$ARCH" = "i386" ]; then
 		export OUT="$TMP_OUT/$ARCH"; mkdir -p $OUT
