@@ -1,22 +1,35 @@
 # Unset all optional variables first to start from a clean state
-unset NONUS
-unset FORCENONUSONCD1
-unset NONFREE
-unset EXTRANONFREE
-unset LOCAL
-unset LOCALDEBS
-unset SECURED
-unset BOOTDIR
-unset SYMLINK
-unset COPYLINK
-unset MKISOFS
-unset MKISOFS_OPTS
-unset EXCLUDE
-unset SRCEXCLUDE
-unset NORECOMMENDS
-unset DOJIGDO
-unset JIGDOCMD
-unset JIGDOTEMPLATEURL
+unset NONUS             || true
+unset FORCENONUSONCD1   || true
+unset NONFREE           || true
+unset CONTRIB           || true
+unset EXTRANONFREE      || true
+unset LOCAL             || true
+unset LOCALDEBS         || true
+unset SECURED           || true
+unset SECURITY          || true
+unset BOOTDIR           || true
+unset BOOTDISKS         || true
+unset SYMLINK           || true
+unset COPYLINK          || true
+unset MKISOFS           || true
+unset MKISOFS_OPTS      || true
+unset ISOLINUX          || true
+unset EXCLUDE           || true
+unset SRCEXCLUDE        || true
+unset NORECOMMENDS      || true
+unset NOSUGGESTS        || true
+unset DOJIGDO           || true
+unset JIGDOCMD          || true
+unset JIGDOTEMPLATEURL  || true
+unset DEFBINSIZE        || true
+unset DEFSRCSIZE        || true
+unset FASTSUMS          || true
+unset PUBLISH_URL       || true
+unset PUBLISH_NONUS_URL || true
+unset PUBLISH_PATH      || true
+unset INSTALLER_CD      || true
+unset DI_CODENAME       || true
 
 
 # The debian-cd dir
@@ -25,8 +38,14 @@ export BASEDIR=/usr/share/debian-cd
 # Building woody cd set ...
 export CODENAME=woody
 
+# By default use Debian installer packages from $CODENAME
+if [ ! "$DI_CODENAME" ]
+then
+  export DI_CODENAME=$CODENAME
+fi
+
 # Version number, "2.2 r0", "2.2 r1" etc.
-export DEBVERSION="3.0 beta"
+export DEBVERSION="3.0"
 
 # Official or non-official set.
 # NOTE: THE "OFFICIAL" DESIGNATION IS ONLY ALLOWED FOR IMAGES AVAILABLE
@@ -67,6 +86,9 @@ export APTTMP=/home/ftp/tmp/apt
 # Do I want to have NONFREE merged in the CD set
 # export NONFREE=1
 
+# Do I want to have CONTRIB merged in the CD set
+export CONTRIB=1
+
 # Do I want to have NONFREE on a separate CD (the last CD of the CD set)
 # WARNING: Don't use NONFREE and EXTRANONFREE at the same time !
 # export EXTRANONFREE=1
@@ -86,6 +108,10 @@ export APTTMP=/home/ftp/tmp/apt
 # uncomment this line
 # export SECURED=1
 
+# Where to find the security patches.  This directory should be the
+# top directory of a security.debian.org mirror.
+#export SECURITY="$TOPDIR"/debian/debian-security
+
 # Sparc only : bootdir (location of cd.b and second.b)
 # export BOOTDIR=/boot
 
@@ -102,6 +128,9 @@ export APTTMP=/home/ftp/tmp/apt
 # export MKISOFS_OPTS="-r -T"		#For normal users
 # export MKISOFS_OPTS="-r -F . -T"	#For symlink farmers
 
+# ISOLinux support for multiboot on CD1 for i386
+export ISOLINUX=1
+
 # uncomment this to if you want to see more of what the Makefile is doing
 #export VERBOSE_MAKE=1
 
@@ -109,6 +138,12 @@ export APTTMP=/home/ftp/tmp/apt
 # the proper official CD run does not work
 #ATTEMPT_FALLBACK=yes
 
+# Set your disk size here in MB. Used in calculating package and
+# source file layouts in build.sh and build_all.sh. Defaults are for
+# CD-R, try ~4600 for DVD-R.
+export DEFBINSIZE=630
+export DEFSRCSIZE=635
+
 # We don't want certain packages to take up space on CD1...
 #export EXCLUDE="$BASEDIR"/tasks/exclude-potato
 # ...but they are okay for other CDs (UNEXCLUDEx == may be included on CD >= x)
@@ -119,10 +154,14 @@ export APTTMP=/home/ftp/tmp/apt
 # We also exclude some source packages
 #export SRCEXCLUDE="$BASEDIR"/tasks/exclude-src-potato
 
-# Set this if only the required (and NOT the recommended/suggested) packages
-# should be added on CDs when a package is added on the CD.
+# Set this if the recommended packages should be skipped when adding 
+# package on the CD.  The default is 'false'.
 #export NORECOMMENDS=1
 
+# Set this if the suggested packages should be skipped when adding 
+# package on the CD.  The default is 'true'.
+#export NOSUGGESTS=1
+
 # Produce jigdo files:
 # 0/unset = Don't do jigdo at all, produce only the full iso image.
 # 1 = Produce both the iso image and jigdo stuff.
@@ -143,3 +182,41 @@ export APTTMP=/home/ftp/tmp/apt
 # in the .jigdo files, which you can edit easily if you want.
 # No trailing slash.
 #export JIGDOTEMPLATEURL="http://this-guy-didnt-configure-debiancd-correctly.com/debian-cd/templates/3.0BETA/%ARCH%"
+
+# If set, use the md5sums from the main archive, rather than calculating
+# them locally
+#export FASTSUMS=1
+
+# a couple of things used by publish_cds, so it can tweak the jigdo files,
+# and knows where to put the results
+export PUBLISH_URL="http://cdimage.debian.org/jigdo-area"
+export PUBLISH_NONUS_URL="http://non-US.cdimage.debian.org/jigdo-area"
+export PUBLISH_PATH="/home/jigdo-area/"
+
+# Where to find the boot disks
+#export BOOTDISKS=$TOPDIR/ftp/skolelinux/boot-floppies
+
+# File with list of packages to include when fetching modules for the
+# first stage installer (debian-installer). One package per line.
+# Lines starting with '#' are comments.  The package order is
+# important, as the packages will be installed in the given order.
+#export UDEB_INCLUDE="$BASEDIR"/data/$CODENAME/udeb_include
+
+# File with list of packages to exclude as above.
+#export UDEB_EXCLUDE="$BASEDIR"/data/$CODENAME/udeb_exclude
+
+# File with list of packages to include when running debootstrap from
+# the first stage installer (currently only supported in
+# debian-installer). One package per line.  Lines starting with '#'
+# are comments.  The package order is important, when will be
+# installed in the given order.
+#export BASE_INCLUDE="$BASEDIR"/data/$CODENAME/base_include
+
+# File with list of packages to exclude as above.
+#export BASE_EXCLUDE="$BASEDIR"/data/$CODENAME/base_exclude
+
+# Only put the installer onto the cd (set NORECOMMENDS,... as well).
+# INSTALLER_CD=0: nothing special (default)
+# INSTALLER_CD=1: just add debian-installer (use TASK=tasks/debian-installer)
+# INSTALLER_CD=2: add d-i and base (use TASK=tasks/debian-installer+kernel)
+#export INSTALLER_CD=0
